==> ut-port-file-6.1.0.tgz: package/CHANGELOG.md <==
<a name="6.1.0"></a>
# [6.1.0](https://github.com/softwaregroup-bg/ut-port-file/compare/v6.1.0-rc-bahur.1...v6.1.0) (2018-03-02)



<a name="6.0.0"></a>
# [6.0.0](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.8.0...v6.0.0) (2017-12-06)


### Bug Fixes

* add dependency ([bc53b47](https://github.com/softwaregroup-bg/ut-port-file/commit/bc53b47))
* remove ut-bus dependency, use es6 ([ac6b41e](https://github.com/softwaregroup-bg/ut-port-file/commit/ac6b41e))



<a name="5.8.0"></a>
# [5.8.0](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.7.0...v5.8.0) (2017-10-26)


### Bug Fixes

* check for null ([f0e6a7f](https://github.com/softwaregroup-bg/ut-port-file/commit/f0e6a7f))


### Features

* add metrics ([91be0f3](https://github.com/softwaregroup-bg/ut-port-file/commit/91be0f3))



<a name="5.7.0"></a>
# [5.7.0](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.9...v5.7.0) (2017-09-28)


### Features

* add metrics ([#3](https://github.com/softwaregroup-bg/ut-port-file/issues/3)) ([5d4189b](https://github.com/softwaregroup-bg/ut-port-file/commit/5d4189b))



<a name="5.6.9"></a>
## [5.6.9](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.8...v5.6.9) (2017-05-22)



<a name="5.6.8"></a>
## [5.6.8](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.7...v5.6.8) (2017-05-22)



<a name="5.6.7"></a>
## [5.6.7](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.6...v5.6.7) (2017-05-22)



<a name="5.6.6"></a>
## [5.6.6](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.5...v5.6.6) (2017-05-22)



<a name="5.6.5"></a>
## [5.6.5](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.4...v5.6.5) (2017-05-22)



<a name="5.6.4"></a>
## [5.6.4](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.3...v5.6.4) (2017-05-22)



<a name="5.6.3"></a>
## [5.6.3](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.2...v5.6.3) (2017-04-24)



<a name="5.6.2"></a>
## [5.6.2](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.1...v5.6.2) (2017-03-23)


### Bug Fixes

* dependencies ([5865c6b](https://github.com/softwaregroup-bg/ut-port-file/commit/5865c6b))
* prevent dir traversal ([085d7d3](https://github.com/softwaregroup-bg/ut-port-file/commit/085d7d3))



<a name="5.6.1"></a>
## [5.6.1](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.0...v5.6.1) (2017-03-08)


### Bug Fixes

* dependencies ([923fd0d](https://github.com/softwaregroup-bg/ut-port-file/commit/923fd0d))



<a name="5.6.0"></a>
# [5.6.0](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.5.0...v5.6.0) (2017-02-16)


### Features

* ability to write/append file ([41493f8](https://github.com/softwaregroup-bg/ut-port-file/commit/41493f8))



<a name="5.5.0"></a>
# [5.5.0](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.4.5...v5.5.0) (2016-12-23)


### Features

* update dependencies ([3570698](https://github.com/softwaregroup-bg/ut-port-file/commit/3570698))



<a name="5.4.5"></a>
## [5.4.5](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.4.4...v5.4.5) (2016-11-07)



<a name="5.4.4"></a>
## [5.4.4](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.4.3...v5.4.4) (2016-09-20)



<a name="5.4.3"></a>
## [5.4.3](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.4.2...v5.4.3) (2016-09-17)



<a name="5.4.2"></a>
## [5.4.2](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.4.1...v5.4.2) (2016-08-12)


### Bug Fixes

* publish to npm ([df99ae4](https://github.com/softwaregroup-bg/ut-port-file/commit/df99ae4))



<a name="5.4.1"></a>
## [5.4.1](https://git.softwaregroup-bg.com/ut5/ut-port-file/compare/v5.3.10...v5.4.1) (2016-07-11)


### Features

* upgrade dependencies ([e23bc26](https://git.softwaregroup-bg.com/ut5/ut-port-file/commit/e23bc26))



<a name="5.3.10"></a>
## [5.3.10](https://git.softwaregroup-bg.com/ut5/ut-port-file/compare/v5.3.9...v5.3.10) (2016-04-15)


### Features

* add Gitlab-ci and Jenkins scripts ([a799916](https://git.softwaregroup-bg.com/ut5/ut-port-file/commit/a799916))



<a name="5.3.9"></a>
## [5.3.9](https://git.softwaregroup-bg.com/ut5/ut-port-file/compare/v5.3.8...v5.3.9) (2016-03-31)


### Bug Fixes

* use constant dependencies ([709ee48](https://git.softwaregroup-bg.com/ut5/ut-port-file/commit/709ee48))



<a name="5.3.8"></a>
## [5.3.8](https://git.softwaregroup-bg.com/ut5/ut-port-file/compare/v5.3.6...v5.3.8) (2016-03-30)


### Bug Fixes

* switch to nexus ([f7c3f33](https://git.softwaregroup-bg.com/ut5/ut-port-file/commit/f7c3f33))

### Features

* ut-tools upgrade ([9eebf99](https://git.softwaregroup-bg.com/ut5/ut-port-file/commit/9eebf99))

==> ut-port-file-7.0.1.tgz: package/CHANGELOG.md <==
## [7.0.1](https://github.com/softwaregroup-bg/ut-port-file/compare/v7.0.0...v7.0.1) (2019-03-22)



# [7.0.0](https://github.com/softwaregroup-bg/ut-port-file/compare/v6.1.0...v7.0.0) (2019-02-02)


### Bug Fixes

* ignore package-lock.json ([d8aa8b2](https://github.com/softwaregroup-bg/ut-port-file/commit/d8aa8b2))
* refactor as class ([#7](https://github.com/softwaregroup-bg/ut-port-file/issues/7)) ([f14e498](https://github.com/softwaregroup-bg/ut-port-file/commit/f14e498))
* refactor errors ([6abd848](https://github.com/softwaregroup-bg/ut-port-file/commit/6abd848))
* remove logLevel ([b5ab910](https://github.com/softwaregroup-bg/ut-port-file/commit/b5ab910))
* remove unused dependencies ([aff3425](https://github.com/softwaregroup-bg/ut-port-file/commit/aff3425))
* upgrade chokidar ([0be918b](https://github.com/softwaregroup-bg/ut-port-file/commit/0be918b))
* upgrade dependencies ([d7d6e89](https://github.com/softwaregroup-bg/ut-port-file/commit/d7d6e89))


### BREAKING CHANGES

* requires upgrade of ut-port and ut-run



<a name="6.1.0"></a>
# [6.1.0](https://github.com/softwaregroup-bg/ut-port-file/compare/v6.1.0-rc-bahur.1...v6.1.0) (2018-03-02)



<a name="6.0.0"></a>
# [6.0.0](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.8.0...v6.0.0) (2017-12-06)


### Bug Fixes

* add dependency ([bc53b47](https://github.com/softwaregroup-bg/ut-port-file/commit/bc53b47))
* remove ut-bus dependency, use es6 ([ac6b41e](https://github.com/softwaregroup-bg/ut-port-file/commit/ac6b41e))



<a name="5.8.0"></a>
# [5.8.0](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.7.0...v5.8.0) (2017-10-26)


### Bug Fixes

* check for null ([f0e6a7f](https://github.com/softwaregroup-bg/ut-port-file/commit/f0e6a7f))


### Features

* add metrics ([91be0f3](https://github.com/softwaregroup-bg/ut-port-file/commit/91be0f3))



<a name="5.7.0"></a>
# [5.7.0](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.9...v5.7.0) (2017-09-28)


### Features

* add metrics ([#3](https://github.com/softwaregroup-bg/ut-port-file/issues/3)) ([5d4189b](https://github.com/softwaregroup-bg/ut-port-file/commit/5d4189b))



<a name="5.6.9"></a>
## [5.6.9](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.8...v5.6.9) (2017-05-22)



<a name="5.6.8"></a>
## [5.6.8](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.7...v5.6.8) (2017-05-22)



<a name="5.6.7"></a>
## [5.6.7](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.6...v5.6.7) (2017-05-22)



<a name="5.6.6"></a>
## [5.6.6](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.5...v5.6.6) (2017-05-22)



<a name="5.6.5"></a>
## [5.6.5](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.4...v5.6.5) (2017-05-22)



<a name="5.6.4"></a>
## [5.6.4](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.3...v5.6.4) (2017-05-22)



<a name="5.6.3"></a>
## [5.6.3](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.2...v5.6.3) (2017-04-24)



<a name="5.6.2"></a>
## [5.6.2](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.1...v5.6.2) (2017-03-23)


### Bug Fixes

* dependencies ([5865c6b](https://github.com/softwaregroup-bg/ut-port-file/commit/5865c6b))
* prevent dir traversal ([085d7d3](https://github.com/softwaregroup-bg/ut-port-file/commit/085d7d3))



<a name="5.6.1"></a>
## [5.6.1](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.6.0...v5.6.1) (2017-03-08)


### Bug Fixes

* dependencies ([923fd0d](https://github.com/softwaregroup-bg/ut-port-file/commit/923fd0d))



<a name="5.6.0"></a>
# [5.6.0](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.5.0...v5.6.0) (2017-02-16)


### Features

* ability to write/append file ([41493f8](https://github.com/softwaregroup-bg/ut-port-file/commit/41493f8))



<a name="5.5.0"></a>
# [5.5.0](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.4.5...v5.5.0) (2016-12-23)


### Features

* update dependencies ([3570698](https://github.com/softwaregroup-bg/ut-port-file/commit/3570698))



<a name="5.4.5"></a>
## [5.4.5](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.4.4...v5.4.5) (2016-11-07)



<a name="5.4.4"></a>
## [5.4.4](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.4.3...v5.4.4) (2016-09-20)



<a name="5.4.3"></a>
## [5.4.3](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.4.2...v5.4.3) (2016-09-17)



<a name="5.4.2"></a>
## [5.4.2](https://github.com/softwaregroup-bg/ut-port-file/compare/v5.4.1...v5.4.2) (2016-08-12)


### Bug Fixes

* publish to npm ([df99ae4](https://github.com/softwaregroup-bg/ut-port-file/commit/df99ae4))



<a name="5.4.1"></a>
## [5.4.1](https://git.softwaregroup.com/ut5/ut-port-file/compare/v5.3.10...v5.4.1) (2016-07-11)


### Features

* upgrade dependencies ([e23bc26](https://git.softwaregroup.com/ut5/ut-port-file/commit/e23bc26))



<a name="5.3.10"></a>
## [5.3.10](https://git.softwaregroup.com/ut5/ut-port-file/compare/v5.3.9...v5.3.10) (2016-04-15)


### Features

* add Gitlab-ci and Jenkins scripts ([a799916](https://git.softwaregroup.com/ut5/ut-port-file/commit/a799916))



<a name="5.3.9"></a>
## [5.3.9](https://git.softwaregroup.com/ut5/ut-port-file/compare/v5.3.8...v5.3.9) (2016-03-31)


### Bug Fixes

* use constant dependencies ([709ee48](https://git.softwaregroup.com/ut5/ut-port-file/commit/709ee48))



<a name="5.3.8"></a>
## [5.3.8](https://git.softwaregroup.com/ut5/ut-port-file/compare/v5.3.6...v5.3.8) (2016-03-30)


### Bug Fixes

* switch to nexus ([f7c3f33](https://git.softwaregroup.com/ut5/ut-port-file/commit/f7c3f33))

### Features

* ut-tools upgrade ([9eebf99](https://git.softwaregroup.com/ut5/ut-port-file/commit/9eebf99))
